==> auth-2.4.0717-sources.jar: com/zing/zalo/zalosdk/auth/internal/a.java <==
package com.zing.zalo.zalosdk.auth.internal;

import android.content.Context;
import android.os.AsyncTask;
import com.zing.zalo.zalosdk.core.helper.AppInfo;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest.Type;
import com.zing.zalo.zalosdk.oauth.OauthStorage;
import com.zing.zalo.zalosdk.oauth.ZaloOpenAPICallback;
import com.zing.zalo.zalosdk.oauth.ZaloSDK;
import java.lang.ref.WeakReference;
import org.json.JSONException;
import org.json.JSONObject;

public final class a {
    public String a = "https://graph.zaloapp.com/v2.0/me";
    private OauthStorage b = null;

    public class a extends AsyncTask<HttpClientRequest, Void, JSONObject> {
        Context a;
        WeakReference<ZaloOpenAPICallback> b;
        final /* synthetic */ a c;

        protected final /* synthetic */ Object doInBackground(Object[] objArr) {
            return a((HttpClientRequest[]) objArr);
        }

        protected final /* synthetic */ void onPostExecute(Object obj) {
            JSONObject jSONObject = (JSONObject) obj;
            if (jSONObject != null) {
                try {
                    if (this.b != null && this.b.get() != null) {
                        ((ZaloOpenAPICallback) this.b.get()).onResult(jSONObject);
                    }
                } catch (Exception e) {
                }
            } else if (this.b != null && this.b.get() != null) {
                ((ZaloOpenAPICallback) this.b.get()).onResult(new JSONObject("{\"error\":-1112}"));
            }
        }

        public a(a aVar, Context ctx, WeakReference<ZaloOpenAPICallback> _mOpenAPICallackAsyn) {
            this.c = aVar;
            this.a = ctx;
            this.b = _mOpenAPICallackAsyn;
        }

        protected final void onPreExecute() {
            super.onPreExecute();
        }

        private JSONObject a(HttpClientRequest... requests) {
            HttpClientRequest request = requests[0];
            if (ZaloSDK.Instance.getOAuthCode() == null || ZaloSDK.Instance.getOAuthCode().equals("")) {
                try {
                    return new JSONObject("{\"error\":-1004}");
                } catch (JSONException e) {
                    e.printStackTrace();
                    return null;
                }
            }
            JSONObject accessToken = this.c.a(this.a);
            if (accessToken == null) {
                try {
                    return new JSONObject("{\"error\":-1008}");
                } catch (JSONException e2) {
                    e2.printStackTrace();
                    return null;
                }
            } else if (!accessToken.has("access_token")) {
                return accessToken;
            } else {
                request.addParams("access_token", accessToken.optString("access_token"));
                return request.getJSON();
            }
        }
    }

    public a(OauthStorage storage) {
        this.b = storage;
    }

    final JSONObject a(Context ctx) {
        JSONObject accessToken = null;
        try {
            JSONObject accessToken2 = new JSONObject(this.b.getAccessTokenNewAPI());
            try {
                accessToken = accessToken2.getLong("expires_in") < System.currentTimeMillis() ? null : accessToken2;
            } catch (Exception e) {
                accessToken = accessToken2;
            }
        } catch (Exception e2) {
        }
        if (accessToken == null) {
            try {
                HttpClientRequest request = new HttpClientRequest(Type.POST, "https://oauth.zaloapp.com/v3/mobile/access_token");
                request.addParams("code", ZaloSDK.Instance.getOAuthCode());
                request.addParams("pkg_name", AppInfo.getPackageName(ctx));
                request.addParams("sign_key", AppInfo.getApplicationHashKey(ctx));
                request.addParams("app_id", ZaloSDK.Instance.getAppID());
                request.addParams("version", ZaloSDK.Instance.getVersion());
                request.addParams("zdevice", ZaloSDK.Instance.getBaseAppInfo().prepareDeviceIdData().toString());
                request.addParams("ztracking", ZaloSDK.Instance.getBaseAppInfo().prepareTrackingData().toString());
                request.addHeader("gid", ZaloSDK.Instance.getDeviceId());
                accessToken = request.getJSON();
                if (accessToken != null && accessToken.optInt("error", -1) >= 0) {
                    accessToken = accessToken.optJSONObject("data");
                    accessToken.put("error", 0);
                    if (accessToken != null) {
                        accessToken.put("expires_in", System.currentTimeMillis() + 1800000);
                        this.b.setAccessTokenNewAPI(accessToken.toString());
                    }
                }
            } catch (JSONException e3) {
            }
        }
        return accessToken;
    }

    public static String a(String[] fields) {
        if (fields == null || fields.length <= 0) {
            return "";
        }
        StringBuffer param = new StringBuffer();
        for (int i = 0; i < fields.length - 1; i++) {
            param.append(fields[i]).append(",");
        }
        param.append(fields[fields.length - 1]);
        return param.toString();
    }
}

==> auth-2.4.0823.1-sources.jar: com/zing/zalo/zalosdk/auth/internal/a.java <==
package com.zing.zalo.zalosdk.auth.internal;

import android.content.Context;
import android.os.AsyncTask;
import com.zing.zalo.zalosdk.core.helper.AppInfo;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest;
import com.zing.zalo.zalosdk.core.http.HttpClientRequest.Type;
import com.zing.zalo.zalosdk.core.servicemap.ServiceMapManager;
import com.zing.zalo.zalosdk.oauth.OauthStorage;
import com.zing.zalo.zalosdk.oauth.ZaloOpenAPICallback;
import com.zing.zalo.zalosdk.oauth.ZaloSDK;
import java.lang.ref.WeakReference;
import org.json.JSONException;
import org.json.JSONObject;

public final class a {
    private OauthStorage a = null;
    private String b = "https://graph.zaloapp.com/v2.0/me";

    public class a extends AsyncTask<HttpClientRequest, Void, JSONObject> {
        Context a;
        WeakReference<ZaloOpenAPICallback> b;
        final /* synthetic */ a c;

        protected final /* synthetic */ Object doInBackground(Object[] objArr) {
            return a((HttpClientRequest[]) objArr);
        }

        protected final /* synthetic */ void onPostExecute(Object obj) {
            JSONObject jSONObject = (JSONObject) obj;
            if (jSONObject != null) {
                try {
                    if (this.b != null && this.b.get() != null) {
                        ((ZaloOpenAPICallback) this.b.get()).onResult(jSONObject);
                    }
                } catch (Exception e) {
                }
            } else if (this.b != null && this.b.get() != null) {
                ((ZaloOpenAPICallback) this.b.get()).onResult(new JSONObject("{\"error\":-1112}"));
            }
        }

        public a(a aVar, Context ctx, WeakReference<ZaloOpenAPICallback> _mOpenAPICallackAsyn) {
            this.c = aVar;
            this.a = ctx;
            this.b = _mOpenAPICallackAsyn;
        }

        protected final void onPreExecute() {
            super.onPreExecute();
        }

        private JSONObject a(HttpClientRequest... requests) {
            HttpClientRequest request = requests[0];
            if (ZaloSDK.Instance.getOAuthCode() == null || ZaloSDK.Instance.getOAuthCode().equals("")) {
                try {
                    return new JSONObject("{\"error\":-1004}");
                } catch (JSONException e) {
                    e.printStackTrace();
                    return null;
                }
            }
            JSONObject accessToken = this.c.a(this.a);
            if (accessToken == null) {
                try {
                    return new JSONObject("{\"error\":-1008}");
                } catch (JSONException e2) {
                    e2.printStackTrace();
                    return null;
                }
            } else if (!accessToken.has("access_token")) {
                return accessToken;
            } else {
                request.addParams("access_token", accessToken.optString("access_token"));
                return request.getJSON();
            }
        }
    }

    public a(OauthStorage storage) {
        this.a = storage;
    }

    final JSONObject a(Context ctx) {
        JSONObject accessToken = null;
        try {
            JSONObject accessToken2 = new JSONObject(this.a.getAccessTokenNewAPI());
            try {
                accessToken = accessToken2.getLong("expires_in") < System.currentTimeMillis() ? null : accessToken2;
            } catch (Exception e) {
                accessToken = accessToken2;
            }
        } catch (Exception e2) {
        }
        if (accessToken == null) {
            try {
                HttpClientRequest request = new HttpClientRequest(Type.POST, ServiceMapManager.getInstance().urlFor("oauth_http_s", "/v3/mobile/access_token"));
                request.addParams("code", ZaloSDK.Instance.getOAuthCode());
                request.addParams("pkg_name", AppInfo.getPackageName(ctx));
                request.addParams("sign_key", AppInfo.getApplicationHashKey(ctx));
                request.addParams("app_id", ZaloSDK.Instance.getAppID());
                request.addParams("version", ZaloSDK.Instance.getVersion());
                request.addParams("zdevice", ZaloSDK.Instance.getBaseAppInfo().prepareDeviceIdData().toString());
                request.addParams("ztracking", ZaloSDK.Instance.getBaseAppInfo().prepareTrackingData().toString());
                request.addHeader("gid", ZaloSDK.Instance.getDeviceId());
                accessToken = request.getJSON();
                if (accessToken != null && accessToken.optInt("error", -1) >= 0) {
                    accessToken = accessToken.optJSONObject("data");
                    accessToken.put("error", 0);
                    if (accessToken != null) {
                        accessToken.put("expires_in", System.currentTimeMillis() + 1800000);
                        this.a.setAccessTokenNewAPI(accessToken.toString());
                    }
                }
            } catch (JSONException e3) {
            }
        }
        return accessToken;
    }

    public static String a(String[] fields) {
        if (fields == null || fields.length <= 0) {
            return "";
        }
        StringBuffer param = new StringBuffer();
        for (int i = 0; i < fields.length - 1; i++) {
            param.append(fields[i]).append(",");
        }
        param.append(fields[fields.length - 1]);
        return param.toString();
    }
}
